
body {
  font-family:"Helvetica Neue Light", "HelveticaNeue-Light", "Helvetica Neue", Calibri, Helvetica, Arial;
}

h3,
p,
#qunit-userAgent,
#qunit-banner,
ol {
  margin: 0;
  padding: 0;
}

li {
  list-style-position: inside;
}

#qunit-tests {
  font-size: smaller;
  /* IE6/7 seem to have trouble displaying an OL with no LI children */
  #border-bottom: 1px solid #fff;
  #margin-bottom: -1px;
}

#qunit-tests li {
  padding: 0.4em 2.5em;
  border-bottom: 1px solid #fff;
  font-size: small;
}

#qunit-tests li ol {
  margin-top: 0.5em;
  padding: 0.5em;
  background-color: #fff;
  -moz-box-shadow: inset 0px 1px 8px #ccc;
  -webkit-box-shadow: inset 0px 1px 8px #ccc;
  box-shadow: inset 0px 1px 8px #ccc;
}

#qunit-tests li ol,
#qunit-header,
#qunit-testresult {
  -moz-border-radius: 10px;
  -webkit-border-radius: 10px;
  border-radius: 10px;
}

#qunit-tests li li {
  border-bottom: none;
  margin: 0.5em;
  background-color: #fff;
  list-style-position: inside;
  padding: 0.4em 0.5em;
}

#qunit-tests li li.pass {
  border-left: 26px solid #0a0;
  background-color: #fff;
  color: #0a0;
}

#qunit-tests li li.fail {
  border-left: 26px solid #f00;
  background-color: #fff;
  color: #f00;
}

#qunit-tests li.pass,
h3,
p {
  color: #913D00;
  background-color: #FDEBDC;
}

h3,
p {
  font-size: small;
  padding: 0.4em 0.5em 0.4em 2.5em;
  border-bottom: 1px solid #fff;
}

h3 a,
p a {
  color: #FF7F00;
}

h3 a:hover,
p a:hover {
  color: #000;
}

#qunit-tests li.fail {
  background-color: #f99;
  color: #000;
}

#qunit-tests li strong {
  cursor: pointer;
}

#qunit-header {
  color: #fff;
  background-color: #FF7F00;
  margin: 0;
  padding: 0.5em 2em;
  -moz-border-radius-bottomright: 0;
  -moz-border-radius-bottomleft: 0;
  -webkit-border-bottom-right-radius: 0;
  -webkit-border-bottom-left-radius: 0;
  border-bottom-right-radius: 0;
  border-bottom-left-radius: 0;
}

#qunit-header h1 {
  float: left;
  margin: 0;
  padding: 0;
  line-height: 2em;
  font-size: x-large;
}

#qunit-header small {
  float: right;
  font-weight: 700;
  line-height: 3.5em;
}

#qunit-header a {
  color: #fff;
}

#qunit-header a:hover {
  color: #000;
}

/* Added span inside #qunit-banner to work around IE6 #id.class bug */
#qunit-banner span {
  display: block;
  height: 5px;
  _overflow: hidden;
}

#qunit-banner.qunit-pass span {
  background-color: #0a0;
}

#qunit-banner.qunit-fail span,
#qunit-testrunner-toolbar {
  background-color: #f99;
}

#qunit-testrunner-toolbar {
  padding: 0;
  /*width: 80%;*/
  padding: 0em 0 0.5em 2em;
  font-size: small;
}

#qunit-userAgent {
  background-color: #913D00;
  color: #fff;
  font-size:  small;
  padding: 0.5em 0 0.5em 2.5em;
}

#qunit-testresult {
  margin: 0;
  font-size:  small;
  color: #913D00;
  background-color: #FDEBDC;
  padding: 0.5em 0.5em 0.5em 2.5em;
  -moz-border-radius-topright: 0;
  -moz-border-radius-topleft: 0;
  -webkit-border-top-right-radius: 0;
  -webkit-border-top-left-radius: 0;
  border-top-right-radius: 0;
  border-top-left-radius: 0;
}

strong b.fail {
  color: #f00;
}

strong b.pass {
  color: #0a0;
}
